import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;
 
import java.text.SimpleDateFormat;
import java.util.Date;
 
import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
 
public class DocumentOrder {
 
    public static final String API_KEY = "<YOUR API KEY HERE>";
    public static final String API_URL = "https://sandbox.esignlive.com/api"; // USE https://apps.e-signlive.com/api FOR PRODUCTION
 
    private static final SimpleDateFormat format = new SimpleDateFormat( "HH:mm:ss" );
 
    public static void main( String... args ) {
 
        EslClient eslClient = new EslClient( API_KEY, API_URL );
 
        DocumentPackage superDuperPackage = newPackageNamed("Policy " + format.format(new Date()))
                 .describedAs("This is a package with a document workflow created using the e-SignLive SDK")
                 .withSigner(newSignerWithEmail("john@email.com")
                        .withFirstName("John")
                        .withLastName("Smith"))
                .withDocument(newDocumentWithName("Second Document")
                        .fromFile("src/main/resources/document.pdf")
                        .atIndex(2)
                        .withSignature(signatureFor("john@email.com")
                                .onPage(0)
                                .atPosition(100, 100)))
                .withDocument(newDocumentWithName("First Document")
                        .fromFile("src/main/resources/document.pdf")
                        .atIndex(1)
                        .withSignature(signatureFor("john@email.com")
                                .onPage(0)
                                .atPosition(100, 100)))
                .build();
 
        PackageId packageId = eslClient.createPackage( superDuperPackage );
 
        eslClient.sendPackage( packageId );
        
     // Reorder the documents: swap the order of the two documents
        eslClient.changePackageStatusToDraft(packageId);
        DocumentPackage postOrderDocumentsPackage = eslClient.getPackage(packageId);
        postOrderDocumentsPackage.getDocument("First Document").setIndex(2);
        postOrderDocumentsPackage.getDocument("Second Document").setIndex(1);
 
        eslClient.getPackageService().orderDocuments(postOrderDocumentsPackage);
 
        eslClient.sendPackage( packageId );
    }
}